searchData={"items":[{"type":"module","title":"Plug.Assign","doc":"Provides a Plug for adding assignments to the current connection.","ref":"Plug.Assign.html"},{"type":"module","title":"Example - Plug.Assign","doc":"plug Plug.Assign, foo: \"foo\", bar: true, baz: 42","ref":"Plug.Assign.html#module-example"},{"type":"module","title":"Example of use in a Phoenix Pipeline - Plug.Assign","doc":"pipeline :admin do\n      plug Plug.Assign, admin: true\n    end","ref":"Plug.Assign.html#module-example-of-use-in-a-phoenix-pipeline"},{"type":"module","title":"Example of use in a Phoenix Controller - Plug.Assign","doc":"defmodule Blog.Admin.PostController do\n      use Blog.Web, :Controller\n\n      plug Plug.Assign, subsection: :posts\n      plug Plug.Assign, %{read_request: true} when action in [:index, :show]\n      ...\n    end","ref":"Plug.Assign.html#module-example-of-use-in-a-phoenix-controller"},{"type":"function","title":"Plug.Assign.call/2","doc":"","ref":"Plug.Assign.html#call/2"},{"type":"function","title":"Plug.Assign.init/1","doc":"","ref":"Plug.Assign.html#init/1"},{"type":"extras","title":"Plug.Assign","doc":"# Plug.Assign\n\nA simple plug to allow setting variables in a connection.  For example, as a way to set default variables for a controller, view or template to use in a Phoenix app.","ref":"readme.html"},{"type":"extras","title":"Installation - Plug.Assign","doc":"The package can be installed from Hex:\n\nAdd plug_assign to your list of dependencies in `mix.exs`:\n\n```elixir\n    def deps do\n      [{:plug_assign, \"~> 2.0.1\"}]\n    end\n```\n\nFetch and install the dependencies\n\n```sh\n    $ mix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Basic Usage - Plug.Assign","doc":"Define assigns as part of any plug stack.\n\n```elixir\n    plug Plug.Assign, foo: \"bar\", bar: true, baz: 42\n```\n\nThis will set the given key/value pairs in the `assigns` map of the Plug.Conn, for you to use\nin controllers, views, and templates.\n\nOne way to use this is to set variables so you can quickly determine where you are in your app.\n\n```elixir\n    pipeline :browser do\n      ...\n      plug Plug.Assign, admin: false\n    end\n\n    pipeline :admin do\n      plug Plug.Assign, admin: true\n    end\n```\n\nAnd then use that in a template, such as your layout.\n\n```html\n   \n     Hello, Administrator \n   \n```\n\nSince you can use this anywhere you can use a plug, you can also use it in a Phoenix Controller.\n\n```elixir\n    defmodule HelloWeb.Admin.PostController do\n      use HelloWeb, :controller\n\n      plug Plug.Assign, section: :posts\n      ...\n    end\n```\n\n```html\n     \n```\n\nIf you want to only assign a variable for certain actions, you can use the `plug ... when` format,\nbut be careful that bare keyword lists are only accepted as the last arguments of a macro call,\nwhich is no longer the case with a `when` clause, so add the square brackets `[]` around your\nassigns, or use a map instead.\n\n```elixir\n    defmodule HelloWeb.Admin.PostController do\n      use HelloWeb, :controller\n\n      plug Plug.Assign, [read_request: true] when action in [:index, :show]\n      plug Plug.Assign, %{write_request: true} when action in [:edit, :new, :create, :update, :delete]\n      ...\n    end\n```","ref":"readme.html#basic-usage"},{"type":"extras","title":"Accessing in templates - Plug.Assign","doc":"If you're using an assign in a template that may not have been set, you can't use the\n`@variable` format without throwing an error, so use one of the following techniques instead:\n\n- Access shortcut: `assigns[:admin]` - Returns `nil` if not set.\n- Map.get/2: `Map.get(assigns, :admin)` - Returns `nil` if not set.\n- Map.get/3: `Map.get(assigns, :admin, false) - `Returns `false` if not set.\n\n```html\n   \n     Hello, Administrator \n   \n```","ref":"readme.html#accessing-in-templates"},{"type":"extras","title":"Assignment formats - Plug.Assign","doc":"Assigns can be either a keyword list\n\n```elixir\n    plug Plug.Assign, foo: \"bar\", bar: true, baz: 42\n```\n\nOr a map, as long as the keys are atoms.\n\n```elixir\n    plug Plug.Assign, %{foo: \"foo\", bar: true, baz: 42}\n    plug Plug.Assign, %{:foo => \"foo\", :bar => true, :baz => 42}\n```\n\nAny attempt to pass it anything else will throw an exception.\n\n```bash\n** (ArgumentError) Invalid assignment, must be a keyword list or map with all keys as atoms\n```","ref":"readme.html#assignment-formats"},{"type":"extras","title":"Generate documentation - Plug.Assign","doc":"```bash\n    mix docs\n```","ref":"readme.html#generate-documentation"},{"type":"extras","title":"MIT License","doc":"# MIT License\n\nCopyright (c) 2015 Nathan Shafer\n\nPermission is hereby granted, free of charge, to any person obtaining\na copy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND\nNONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE\nLIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION\nOF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION\nWITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}],"content_type":"text/markdown"}